@@ -26,7 +26,7 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "Ο %1$s κατάργησε την κοινή χρήση του φακέλου «%2$s» μαζί σας",
     "Someone unshared folder \"%s\" with you" : "Κάποιος κατάργησε την κοινή χρήση του φακέλου «%s» μαζί σας",
     "No file provided for import" : "Κανένα αρχείο για εισαγωγή",
-    "Unsupported file type for import" : "Μη υποστηριζόμενος τύπος αρχείου",
+    "Unsupported file type for import" : "Μη υποστηριζόμενος τύπος αρχείου για εισαγωγή",
     "Bookmarks shared by %s" : "Σελιδοδείκτες σε κοινή χρήση από %s",
     "Frequent bookmarks" : "Συχνοί σελιδοδείκτες",
     "Recent bookmarks" : "Τελευταίοι σελιδοδείκτες",
@@ -112,10 +112,6 @@ OC.L10N.register(
     "Install on home screen" : "Εγκατάσταση στην αρχική οθόνη",
     "Bookmarklet" : "Εφαρμογίδιο Σελιδοδεικτών",
     "Add to {instanceName}" : "Προσθήκη στο {instanceName}",
-    "Clear data" : "Εκκαθάριση δεδομένων",
-    "Permanently remove all bookmarks from your account." : "Οριστική διαγραφή όλων των σελιδοδεικτών από το λογαριασμό σας.",
-    "Delete all bookmarks" : "Διαγραφή όλων των σελιδοδεικτών",
-    "Do you really want to delete all your bookmarks?" : "Θέλετε σίγουρα να διαγράψετε όλους σας τους σελιδοδείκτες;",
     "Please select \"Add to home screen\" in your browser menu" : "Παρακαλούμε επιλέξτε «Προσθήκη στην αρχική οθόνη» από το μενού του περιηγητή",
     "Title" : "Τίτλος",
     "Link" : "Σύνδεσμος",
