@@ -20,9 +20,6 @@ OC.L10N.register(
     "Import" : "Import",
     "Export" : "Export",
     "Bookmarklet" : "Bookmarklet",
-    "Clear data" : "Clear data",
-    "Delete all bookmarks" : "Delete all bookmarks",
-    "Do you really want to delete all your bookmarks?" : "Do you really want to delete all your bookmarks?",
     "Title" : "Title",
     "Link" : "Link",
     "Tags" : "Tags",
