@@ -92,10 +92,6 @@ OC.L10N.register(
     "Install on home screen" : "Instalar na pantalla de inicio",
     "Bookmarklet" : "Miniaplicación ligada",
     "Add to {instanceName}" : "Engadir a {instanceName}",
-    "Clear data" : "Limpar os datos",
-    "Permanently remove all bookmarks from your account." : "Retirar de xeito permanente todos os marcadores da súa conta.",
-    "Delete all bookmarks" : "Eliminar todos os marcadores",
-    "Do you really want to delete all your bookmarks?" : "Confirma que quere eliminar todos os seus marcadores?",
     "Please select \"Add to home screen\" in your browser menu" : "Seleccione «Engadir na pantalla de inicio» no menú do seu navegador",
     "Title" : "Título",
     "Link" : "Ligazón",
