@@ -117,12 +117,15 @@ OC.L10N.register(
     "{used} bookmarks of {available} available" : "{used} segnalibri di {available} disponibili",
     "No bookmarked files" : "Nessun file come segnalibro",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "I segnalibri per file come foto o PDF saranno automaticamente salvati nei tuoi file di Nextcloud, in modo che tu possa trovarli anche quando non sei in linea.",
+    "No shared folders" : "Nessuna cartella condivisa",
+    "No duplicated bookmarks" : "Nessun segnalibro duplicato",
     "No bookmarks here" : "Nessun segnalibro qui",
     "Add bookmarks manually or import bookmarks from a HTML file." : "Aggiungi i segnalibri manualmente o importa i segnalibri da un file HTML.",
     "Import" : "Importa",
     "Export" : "Esporta",
     "Archive path" : "Percorso dell'archivio",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "Inserisci il percorso di una cartella nei tuoi File dove conservare i file con segnalibro.",
+    "Backups" : "Backup",
     "Client apps" : "Applicazioni client",
     "Also check out the collection of client apps that integrate with this app: " : "Controlla inoltre l'elenco delle applicazioni client che si integrano con questa applicazione:",
     "Install web app on device" : "Installa l'applicazione web sul dispositivo",
@@ -135,6 +138,7 @@ OC.L10N.register(
     "Title" : "Titolo",
     "Link" : "Collegamento",
     "Untitled folder" : "Cartella senza nome",
+    "Root folder" : "Cartella radice",
     "Tags" : "Etichette",
     "Select tags and create new ones" : "Seleziona le etichette o creane di nuove",
     "Notes" : "Note",
@@ -142,6 +146,7 @@ OC.L10N.register(
     "Archived file" : "File archiviato",
     "Open file" : "Apri file",
     "Open file location" : "Apri percorso file",
+    "Projects" : "Progetti",
     "Created {time} ago" : "Creato {time} fa",
     "Created on {date}" : "Creato il {date}",
     "Owner" : "Proprietario",
