@@ -19,9 +19,6 @@ OC.L10N.register(
     "Import" : "Importēt",
     "Export" : "Eksportēt",
     "Bookmarklet" : "Grāmatzīme",
-    "Clear data" : "Notīrīt datus",
-    "Delete all bookmarks" : "Dzēst visas grāmatzīmes",
-    "Do you really want to delete all your bookmarks?" : "Vai tiešām vēlaties dzēst visas savas grāmatzīmes?",
     "Title" : "Amats",
     "Link" : "Saite",
     "Tags" : "Birkas",
