@@ -37,9 +37,6 @@ OC.L10N.register(
     "Import" : "Importer",
     "Export" : "Eksporter",
     "Bookmarklet" : "Bookmarklet",
-    "Clear data" : "Tøm data",
-    "Delete all bookmarks" : "Slett alle bokmerker",
-    "Do you really want to delete all your bookmarks?" : "Er du sikker på at du vil slette alle dine bokmerker",
     "Title" : "Tittel",
     "Link" : "Lenke",
     "Tags" : "Merkelapper",
