@@ -126,10 +126,6 @@ OC.L10N.register(
     "Bookmarklet" : "小书签",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "将此拖到浏览器书签中，并单击它可快速将网页添加为书签。",
     "Add to {instanceName}" : "添加到 {instanceName}",
-    "Clear data" : "清除数据",
-    "Permanently remove all bookmarks from your account." : "从您的账户中永久删除所有书签",
-    "Delete all bookmarks" : "删除所有书签",
-    "Do you really want to delete all your bookmarks?" : "您确定准备好删除所有的书签吗？",
     "Please select \"Add to home screen\" in your browser menu" : "请点击浏览器菜单中的“添加到主屏幕”",
     "Title" : "标题",
     "Link" : "链接",
