@@ -132,8 +132,9 @@ OC.L10N.register(
     "Export" : "導出",
     "Archive path" : "封存路徑",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "輸入應該存儲書籤檔案的資料夾的路徑",
-    "Backup path" : "備份路徑",
-    "Enter the path of a folder in your Files where your bookmarks backups will be stored." : "輸入應該存儲書籤複本的資料夾的路徑",
+    "Backups" : "備份",
+    "Enable bookmarks backups" : "啟用書籤備份",
+    "Enter the path of a folder in your Files where backups will be stored." : "輸入在您「檔案」中要儲存備份的資料夾路徑。",
     "Client apps" : "客戶端 apps",
     "Also check out the collection of client apps that integrate with this app: " : "還請檢查與此應用程序集成的客戶端應用程序的集合：",
     "Install web app on device" : "在設備上安裝 web 應用程式",
@@ -142,6 +143,7 @@ OC.L10N.register(
     "Bookmarklet" : "書籤",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "將此拖拉到您瀏覽器書籤中且點擊它以快速為網頁添加書籤。",
     "Add to {instanceName}" : "加到 {instanceName}",
+    "Backup path" : "備份路徑",
     "Please select \"Add to home screen\" in your browser menu" : "請在瀏覽器菜單中選擇“添加到主屏幕”",
     "Title" : "標題",
     "Link" : "連結",
